@@ -102,11 +102,14 @@ class HierarchyNameWithParentsFilter(HierarchyFilter):
     """
 
     def get_filter_for_hierarchy(self, hierarchy_model, filter_value):
+        filter_parts = [value.strip() for value in filter_value.split(',') if value]
+        hierarchy_filter = Q(isactive=True)
+
+        for part in filter_parts:
+            hierarchy_filter &= Q(name_with_parents__icontains=part)
+
         return Q(
-            objectid__in=hierarchy_model.objects.filter(**{
-                'isactive': True,
-                'name_with_parents__icontains': filter_value,
-            }).values('objectid'),
+            objectid__in=hierarchy_model.objects.filter(hierarchy_filter).values('objectid'),
         )
 
 
