@@ -48,59 +48,12 @@ class HierarchySerializer(serializers.ModelSerializer):
     """
     objectid = ReestrObjectsSerializer()
     parentobjid = ReestrObjectsSerializer()
-    name_with_parents = serializers.SerializerMethodField()
     has_children = serializers.SerializerMethodField()
 
     class Meta:
         model = Hierarchy
         fields = '__all__'
 
-    def get_name_with_parents(self, obj):
-        result_parts = []
-        for item in obj.get_ancestors(include_self=True):
-            try:
-                addr_obj = AddrObj.objects.get(
-                    objectid=item.objectid_id,
-                    isactual=True,
-                )
-                official_type = ParamTypes.objects.filter(code=CODE_PARAM_TYPES_OFFICIAL, isactive=True)
-                official_param = None
-                if official_type:
-                    official_param = AddrObjParams.objects.filter(
-                        objectid=item.objectid_id,
-                        typeid=official_type.get(),
-                    )
-            except:
-                print('error')
-            else:
-                type_name = addr_obj.type_full_name
-                # Если Респ, то Республика, а если г., то город
-                if addr_obj.typename and addr_obj.typename[0].islower():
-                    type_name = type_name.lower()
-
-                # Делаем так, чтобы не "область Кировская", а "Кировская область"
-                # Впрочем, если есть официальное название, то используем его. 
-                # Перестановки остаются на уровне районов, городов и т.д.
-                if official_param:
-                    for actual_param in official_param:
-                        # Может быть два официальных названия: Пермский край и Пермская область. Используем то,
-                        # которое используется на данный момент.
-                        if type_name in actual_param.value:
-                            official_name = actual_param.value
-                            break
-
-                    addr_obj_name = f'{official_name}'
-                elif addr_obj.is_prefix_type:
-                    addr_obj_name = f'{type_name} {addr_obj.name}'
-                else:
-                    addr_obj_name = f'{addr_obj.name} {type_name}'
-
-                result_parts.append(addr_obj_name)
-
-        result = ', '.join(result_parts)
-
-        return result
-
     def get_has_children(self, obj):
         return obj.has_children
 
