@@ -6,12 +6,14 @@ from m3_gar.models import (
     AddrObj,
     Apartments,
     Houses,
+    Steads,
     Rooms,
 )
 from m3_rest_gar.filters import (
     AddrObjFilter,
     ApartmentsFilter,
     HousesFilter,
+    SteadsFilter,
     RoomsFilter,
 )
 from m3_rest_gar.mixins import (
@@ -21,6 +23,7 @@ from m3_rest_gar.serializers import (
     AddrObjSerializer,
     ApartmentsSerializer,
     HousesSerializer,
+    SteadsSerializer,
     RoomsSerializer,
 )
 
@@ -61,6 +64,20 @@ class HousesViewSet(BaseAddrObjReadOnlyViewSet):
     filterset_class = HousesFilter
 
 
+class SteadsViewSet(BaseAddrObjReadOnlyViewSet):
+    queryset = Steads.objects.filter(
+        isactive=True,
+        isactual=True,
+    ).select_related(
+        'objectid',
+    ).order_by(
+        'objectid',
+    )
+
+    serializer_class = SteadsSerializer
+    filterset_class = SteadsFilter
+
+
 class ApartmentsViewSet(BaseAddrObjReadOnlyViewSet):
     queryset = Apartments.objects.filter(
         isactive=True,
